# Table of Contents

- [sap-suggestions-in-reports](<./sap-suggestions-in-reports.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP Suggestions in Reports](<./SAP-Suggestions-in-Reports.md>)
  - [Overview](<./SAP-Suggestions-in-Reports/Overview.md>)
  - [Prerequisites](<./SAP-Suggestions-in-Reports/Prerequisites.md>)
  - [Available Reports](<./SAP-Suggestions-in-Reports/Available-Reports.md>)
  - [Enabling SAP Suggestions](<./SAP-Suggestions-in-Reports/Enabling-SAP-Suggestions.md>)
  - [Displaying SAP Suggestions](<./SAP-Suggestions-in-Reports/Displaying-SAP-Suggestions.md>)
  - [Viewing SAP Suggestions in Reports](<./SAP-Suggestions-in-Reports/Viewing-SAP-Suggestions-in-Reports.md>)
  - [Creating Fact Sheets from SAP Suggestions](<./SAP-Suggestions-in-Reports/Creating-Fact-Sheets-from-SAP-Suggestions.md>)
  - [Using SAP Suggestions for Strategic Planning and Optimization](<./SAP-Suggestions-in-Reports/Using-SAP-Suggestions-for-Strategic-Planning-and-Optimization.md>)
